==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ZoomSliderResolvingAxisValueEventArgsDescription } from "./ZoomSliderResolvingAxisValueEventArgsDescription";
/**
 * @hidden
 */
export let ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a == null) {
                ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.c(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a);
            }
            if (a.k(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Position", "Number:double");
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        }
        static d(a) {
            ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.b(a);
            a.ad("ZoomSliderResolvingAxisValueEventArgs", () => new ZoomSliderResolvingAxisValueEventArgsDescription());
            a.ac("ZoomSliderResolvingAxisValueEventArgs", ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a);
        }
    }
    ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.$t = markType(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata, 'ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata');
    ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a = null;
    return ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ZoomSliderResolvingAxisValueEventArgsDescription } from "./ZoomSliderResolvingAxisValueEventArgsDescription";
/**
 * @hidden
 */
export let ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a == null) {
                ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.c(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a);
            }
            if (a.k(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Position", "Number:double");
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        }
        static d(a) {
            ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.b(a);
            a.ae("ZoomSliderResolvingAxisValueEventArgs", () => new ZoomSliderResolvingAxisValueEventArgsDescription());
            a.ad("ZoomSliderResolvingAxisValueEventArgs", ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a);
        }
    }
    ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.$t = markType(ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata, 'ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata');
    ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.a = null;
    return ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata;
})();
